@@ -14,7 +14,7 @@
    +----------------------------------------------------------------------+
 */
 
-#define CONFIGURE_COMMAND " './configure'  'ax_cv_have_func_attribute_ifunc=no' '--program-suffix=83' '--with-config-file-path=/usr/pkg/etc/php/8.3' '--with-config-file-scan-dir=/usr/pkg/etc/php/8.3/php.d' '--with-pear=/usr/pkg/{PHP_LIBDIR}' '--sysconfdir=/usr/pkg/etc/php/8.3' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--with-external-pcre' '--disable-intl' '--disable-posix' '--disable-opcache' '--disable-pdo' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=aarch64_be--netbsd' '--host=aarch64_be--netbsd' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=aarch64_be--netbsd' 'host_alias=aarch64_be--netbsd' 'PKG_CONFIG=/usr/pkg/bin/pkg-config' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/usr/pkg/lib/pkgconfig:/usr/pkg/share/pkgconfig:/usr/lib/pkgconfig:/usr/X11R7/lib/pkgconfig' 'LIBS='"
+#define CONFIGURE_COMMAND " './configure'  'ax_cv_have_func_attribute_ifunc=no' '--program-suffix=83' '--with-config-file-path=/usr/pkg/etc/php/8.3' '--with-config-file-scan-dir=/usr/pkg/etc/php/8.3/php.d' '--sysconfdir=/usr/pkg/etc/php/8.3' '--libdir=/usr/pkg/lib/php/8.3' '--datadir=/usr/pkg/share/php/8.3' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--with-external-pcre' '--disable-intl' '--disable-posix' '--disable-opcache' '--disable-pdo' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=m68k--netbsdelf' '--host=m68k--netbsdelf' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=m68k--netbsdelf' 'host_alias=m68k--netbsdelf' 'PKG_CONFIG=/usr/pkg/bin/pkg-config' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/usr/pkg/lib/pkgconfig:/usr/pkg/share/pkgconfig:/usr/lib/pkgconfig:/usr/X11R7/lib/pkgconfig' 'LIBS='"
 #define PHP_ODBC_CFLAGS	""
 #define PHP_ODBC_LFLAGS		""
 #define PHP_ODBC_LIBS		""
@@ -24,13 +24,13 @@
 #define PHP_PROG_SENDMAIL	"/usr/sbin/sendmail"
 #define PEAR_INSTALLDIR         ""
 #define PHP_INCLUDE_PATH	".:"
-#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/8.3/aarch64_be"
+#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/8.3/m68k"
 #define PHP_PREFIX              "/usr/pkg"
 #define PHP_BINDIR              "/usr/pkg/bin"
 #define PHP_SBINDIR             "/usr/pkg/sbin"
 #define PHP_MANDIR              "/usr/pkg/man"
-#define PHP_LIBDIR              "/usr/pkg/lib/php/"
-#define PHP_DATADIR             "/usr/pkg/share/php/"
+#define PHP_LIBDIR              "/usr/pkg/lib/php/8.3"
+#define PHP_DATADIR             "/usr/pkg/share/php/8.3"
 #define PHP_SYSCONFDIR          "/usr/pkg/etc/php/8.3"
 #define PHP_LOCALSTATEDIR       "/var"
 #define PHP_CONFIG_FILE_PATH    "/usr/pkg/etc/php/8.3"
